@@ -5,7 +5,7 @@
 import ephem._libastro as _libastro
 from math import pi
 
-__version__ = '3.7.3.3'
+__version__ = '3.7.3.4'
 
 twopi = pi * 2.
 halfpi = pi / 2.
@@ -247,9 +247,22 @@ class Observer(_libastro.Observer):
                    self.long, self.lat, self.elevation,
                    self.horizon, self.temp, self.pressure))
 
+    def compute_pressure(self):
+        """Set the atmospheric pressure for the current elevation."""
+        # Formula from the ISA Standard Atmosphere
+        self.pressure = (1013.25 * (1 - 0.0065 * self.elevation / 288.15)
+                         ** 5.2558761132785179)
+
     def _compute_transit(self, body, start, sign, offset):
         """Internal function used to compute transits."""
 
+        if isinstance(body, EarthSatellite):
+            raise TypeError(
+                'the next and previous transit methods do not'
+                ' support earth satellites because of their speed;'
+                ' please use the higher-resolution next_pass() method'
+                )
+
         def f(d):
             self.date = d
             body.compute(self)
@@ -309,6 +322,13 @@ class Observer(_libastro.Observer):
     def _riset_helper(self, body, start, rising, previous):
         """Internal function for finding risings and settings."""
 
+        if isinstance(body, EarthSatellite):
+            raise TypeError(
+                'the rising and settings methods do not'
+                ' support earth satellites because of their speed;'
+                ' please use the higher-resolution next_pass() method'
+                )
+
         def visit_transit():
             d = (previous and self.previous_transit(body)
                  or self.next_transit(body)) # if-then
@@ -388,6 +408,17 @@ class Observer(_libastro.Observer):
         """Move to the given body's next setting, returning the date."""
         return self._riset_helper(body, start, False, False)
 
+    def next_pass(self, body):
+        """Return the next rising, culmination, and setting of a satellite."""
+
+        if not isinstance(body, EarthSatellite):
+            raise TypeError(
+                'the next_pass() method is only for use with'
+                ' EarthSatellite objects because of their high speed'
+                )
+
+        return _libastro._next_pass(self, body)
+
 # Time conversion.
 
 def localtime(date):
