@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from ephem_test import unittest, MyTestCase
+from .ephem_test import unittest, MyTestCase
 import ephem
 
 # Make sure that a series of next-risings does not keep returning the
@@ -10,6 +10,7 @@ import ephem
 class next_rising_suite(MyTestCase):
     def runTest(self):
         boston = ephem.city("Boston")
+        boston.pressure = 1010.0 # undo pressure auto-adjustment
         mars = ephem.Mars()
         cur_date = ephem.Date("2009/6/29 07:00:00")
 
